# recette

Data preprocessing utilities on top of [pandas](https://pandas.pydata.org/) inspired by [tidymodels' recipes package](https://tidymodels.github.io/recipes/). My aim isn't to port recipes to Python 3, but just to use some of its features I found nice. I'm also interested in exploring pandas extension data types. I expect this to give me a higher flexibility in dealing with categorical columns, by using the category data type, and NAs, due to the new nullable data types. As a final note, I'm currently treating this package as an experiment, so its direction may change unexpectedly.
